@@ -10,6 +10,7 @@ import pandas as pd
 from pandas.api.types import CategoricalDtype
 import time
 
+from reV.version import __version__
 from reV.handlers.resource import Resource
 from reV.handlers.parse_keys import parse_keys
 from reV.utilities.exceptions import (HandlerRuntimeError, HandlerKeyError,
@@ -48,16 +49,19 @@ class Outputs(Resource):
         self._str_decode = str_decode
         self._group = self._check_group(group)
 
+        if self.writable:
+            self.set_version_attr()
+
     def __len__(self):
         _len = 0
-        if 'meta' in self.dsets:
+        if 'meta' in self.datasets:
             _len = super().__len__()
 
         return _len
 
     def __getitem__(self, keys):
         ds, ds_slice = parse_keys(keys)
-        if ds in self.dsets:
+        if ds in self.datasets:
             if ds.endswith('time_index'):
                 out = self._get_time_index(ds, *ds_slice)
             elif ds.endswith('meta'):
@@ -85,6 +89,46 @@ class Outputs(Resource):
             else:
                 self._set_ds_array(ds, arr, *ds_slice)
 
+    def set_version_attr(self):
+        """Set the version attribute to the h5 file."""
+        self.h5.attrs['version'] = __version__
+        self.h5.attrs['package'] = 'reV'
+
+    @property
+    def version(self):
+        """
+        Version of package used to create file
+
+        Returns
+        -------
+        str
+        """
+        return self.h5.attrs['version']
+
+    @property
+    def package(self):
+        """
+        Package used to create file
+
+        Returns
+        -------
+        str
+        """
+        return self.h5.attrs['package']
+
+    @property
+    def source(self):
+        """
+        Package and version used to create file
+
+        Returns
+        -------
+        str
+        """
+        out = ("{}_{}"
+               .format(self.h5.attrs['package'], self.h5.attrs['version']))
+        return out
+
     @property
     def shape(self):
         """
@@ -96,7 +140,7 @@ class Outputs(Resource):
             shape of variables arrays == (time, locations)
         """
         _shape = None
-        dsets = self.dsets
+        dsets = self.datasets
         if 'meta' in dsets:
             _shape = self.h5['meta'].shape
             if 'time_index' in dsets:
@@ -111,15 +155,15 @@ class Outputs(Resource):
 
         Returns
         -------
-        bool
+        is_writable : bool
             Flag if mode is writable
         """
+        is_writable = True
         mode = ['a', 'w', 'w-', 'x']
         if self._mode not in mode:
-            raise HandlerRuntimeError('mode must be writable: {}'
-                                      .format(mode))
+            is_writable = False
 
-        return True
+        return is_writable
 
     @Resource.meta.setter  # pylint: disable-msg=E1101
     def meta(self, meta):
@@ -155,7 +199,7 @@ class Outputs(Resource):
         configs : dict
             Dictionary of SAM configuration JSONs
         """
-        if 'meta' in self.dsets:
+        if 'meta' in self.datasets:
             configs = {k: json.loads(v)
                        for k, v in self.h5['meta'].attrs.items()}
         else:
@@ -226,7 +270,7 @@ class Outputs(Resource):
         if isinstance(meta, pd.DataFrame):
             meta = self.to_records_array(meta)
 
-        if ds in self.dsets:
+        if ds in self.datasets:
             self.update_dset(ds, meta)
         else:
             self._create_dset(ds, meta.shape, meta.dtype, data=meta,
@@ -249,7 +293,7 @@ class Outputs(Resource):
         if isinstance(time_index, pd.DatetimeIndex):
             time_index = np.array(time_index.astype(str), dtype='S20')
 
-        if ds in self.dsets:
+        if ds in self.datasets:
             self.update_dset(ds, time_index)
         else:
             self._create_dset(ds, time_index.shape, time_index.dtype,
@@ -269,7 +313,7 @@ class Outputs(Resource):
         config : dict
             SAM config JSON as a dictionary
         """
-        if 'meta' in self.dsets:
+        if 'meta' in self.datasets:
             config = json.loads(self.h5['meta'].attrs[config_name])
         else:
             config = None
@@ -411,7 +455,7 @@ class Outputs(Resource):
         ds_slice : tuple
             Dataset slicing that corresponds to arr
         """
-        if ds_name not in self.dsets:
+        if ds_name not in self.datasets:
             msg = '{} must be initialized!'.format(ds_name)
             raise HandlerRuntimeError(msg)
 
